@@ -1,4 +1,4 @@
-from .data import Paperset, download
+from .data import Paperset, download, search
 from .hopkins import get_hopkins
 from .text import _get_text as text
 from .text import get_texts as texts
